package WebDAO::Lexer::Lobjectref;
#$Id$

=head1 NAME

WebDAO::Lexer::Lobjectref - Process objectref tag

=head1 SYNOPSIS

=head1 DESCRIPTION

WebDAO::Lexer::Lobjectref - Process objectref tag

=cut

use WebDAO::Lexer::Lbase;
use Data::Dumper;
use base qw( WebDAO::Lexer::Lregclass );
use strict;
1;
